https://github.com/python/cpython/commit/a68a9190498a16ab1a5c9012ef5a70df81a5b328
commit: a68a9190498a16ab1a5c9012ef5a70df81a5b328
branch: 3.14
author: Hugo van Kemenade <[email protected]>
committer: hugovk <[email protected]>
date: 2026-05-04T18:31:40+03:00
summary:

Python 3.14.5rc1

files:
A Misc/NEWS.d/3.14.5rc1.rst
D Misc/NEWS.d/next/Build/2026-03-21-18-51-31.gh-issue-146264.Q9Ej4m.rst
D Misc/NEWS.d/next/Build/2026-04-14-15-20-29.gh-issue-148535.JjKiaa.rst
D Misc/NEWS.d/next/Build/2026-04-30-08-43-47.gh-issue-146475.1cL4hX.rst
D Misc/NEWS.d/next/Build/2026-05-04-06-03-50.gh-issue-149351.hN4sF0.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-03-26-08-49-35.gh-issue-146455.f54083a9.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-02-13-25-09.gh-issue-147998.wnzkRT.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-07-21-30.gh-issue-137814.6yRTeu.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-20-21-44.gh-issue-148208.JAxpDU.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-20-37-23.gh-issue-148222.uF4D4E.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-09-14-18-33.gh-issue-148037.aP3CSX.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-10-14-20-54.gh-issue-148284.HKs-S_.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-11-17-28-52.gh-issue-148393.lX6gwN.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-12-10-40-57.gh-issue-148418.ggA1LZ.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-12-17-27-28.gh-issue-148390.MAhw7F.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-17-11-30-00.gh-issue-142516.GcGen315.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-17-20-37-02.gh-issue-148653.nbbHMh.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-21-14-36-44.gh-issue-148820.XhOGhA.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-22-14-55-18.gh-issue-113956.0VEXd6.rst
D 
Misc/NEWS.d/next/Core_and_Builtins/2026-04-29-14-06-00.gh-issue-149122.P8k2Lm.rst
D 
Misc/NEWS.d/next/Documentation/2026-04-02-07-20-00.gh-issue-146646.GlobDoc1.rst
D Misc/NEWS.d/next/Documentation/2026-04-17-02-28-55.gh-issue-148663.MHIbRB.rst
D Misc/NEWS.d/next/Library/2023-09-08-13-10-32.gh-issue-83281.2Plpcj.rst
D Misc/NEWS.d/next/Library/2024-02-10-21-25-22.gh-issue-70039.6wvcAP.rst
D Misc/NEWS.d/next/Library/2025-04-17-15-26-35.gh-issue-132631.IDFZfb.rst
D Misc/NEWS.d/next/Library/2025-10-18-12-13-39.gh-issue-140287.49iU-4.rst
D Misc/NEWS.d/next/Library/2026-01-19-21-23-18.gh-issue-105936.dGrzjM.rst
D 
Misc/NEWS.d/next/Library/2026-02-22-00-00-00.gh-issue-145105.csv-reader-reentrant.rst
D Misc/NEWS.d/next/Library/2026-03-11-15-09-52.gh-issue-145831._sW94w.rst
D Misc/NEWS.d/next/Library/2026-03-22-23-42-22.gh-issue-146313.RtDeAd.rst
D Misc/NEWS.d/next/Library/2026-04-07-14-13-40.gh-issue-148192.34AUYQ.rst
D Misc/NEWS.d/next/Library/2026-04-09-12-42-42.gh-issue-148254.Xt7vKs.rst
D Misc/NEWS.d/next/Library/2026-04-12-16-40-11.gh-issue-148370.0Li2EK.rst
D Misc/NEWS.d/next/Library/2026-04-13-06-22-27.gh-issue-148464.Bj_NZy.rst
D Misc/NEWS.d/next/Library/2026-04-13-15-59-44.gh-issue-148518.RQdvsu.rst
D Misc/NEWS.d/next/Library/2026-04-14-09-04-35.gh-issue-148508.-GiXml.rst
D Misc/NEWS.d/next/Library/2026-04-15-11-00-39.gh-issue-146553.VGOsoP.rst
D Misc/NEWS.d/next/Library/2026-04-16-13-30-00.gh-issue-148651.ZsTdLk.rst
D Misc/NEWS.d/next/Library/2026-04-18-17-37-13.gh-issue-148740.sYnFi0.rst
D Misc/NEWS.d/next/Library/2026-04-18-21-39-15.gh-issue-148735.siw6DG.rst
D Misc/NEWS.d/next/Library/2026-04-20-18-29-21.gh-issue-148801.ROeNqs.rst
D Misc/NEWS.d/next/Library/2026-04-23-07-38-04.gh-issue-148680.___ePl.rst
D Misc/NEWS.d/next/Library/2026-04-23-21-47-49.gh-issue-148947.W4V2lG.rst
D Misc/NEWS.d/next/Library/2026-04-27-17-12-11.gh-issue-148914.i5C3kW.rst
D Misc/NEWS.d/next/Library/2026-04-27-22-34-09.gh-issue-148093.9pWceM.rst
D Misc/NEWS.d/next/Library/2026-04-29-14-33-42.gh-issue-149148.EaiYvk.rst
D Misc/NEWS.d/next/Library/2026-04-29-16-11-27.gh-issue-149117.yEeTYd.rst
D Misc/NEWS.d/next/Library/2026-05-02-12-03-48.gh-issue-149221.__KOks.rst
D Misc/NEWS.d/next/Security/2026-03-20-09-29-42.gh-issue-146211.PQVbs7.rst
D Misc/NEWS.d/next/Security/2026-03-25-00-51-03.gh-issue-146333.LqdL__bn.rst
D Misc/NEWS.d/next/Security/2026-03-29-12-51-33.gh-issue-146581.4vZfB0.rst
D Misc/NEWS.d/next/Security/2026-03-31-09-15-51.gh-issue-148169.EZJzz2.rst
D Misc/NEWS.d/next/Security/2026-04-10-16-28-21.gh-issue-148395.kfzm0G.rst
D Misc/NEWS.d/next/Security/2026-04-20-15-31-37.gh-issue-148808._Z8JL0.rst
D Misc/NEWS.d/next/Security/2026-04-21-13-46-30.gh-issue-90309.srvj9q.rst
D Misc/NEWS.d/next/Security/2026-04-26-17-49-58.gh-issue-149017.EiVFPo.rst
D Misc/NEWS.d/next/Security/2026-05-02-16-22-20.gh-issue-149254.9ozXB9.rst
D Misc/NEWS.d/next/Windows/2026-03-27-22-06-10.gh-issue-146458.fYj0UQ.rst
D Misc/NEWS.d/next/Windows/2026-05-03-14-07-51.gh-issue-149254.ENtMYD.rst
D Misc/NEWS.d/next/macOS/2026-05-01-19-38-16.gh-issue-149254.enO7uj.rst
M Include/patchlevel.h
M Lib/pydoc_data/module_docs.py
M Lib/pydoc_data/topics.py
M README.rst

diff --git a/Include/patchlevel.h b/Include/patchlevel.h
index a9f72493bdea71..aa961d8e9a3d5e 100644
--- a/Include/patchlevel.h
+++ b/Include/patchlevel.h
@@ -19,12 +19,12 @@
 /*--start constants--*/
 #define PY_MAJOR_VERSION        3
 #define PY_MINOR_VERSION        14
-#define PY_MICRO_VERSION        4
-#define PY_RELEASE_LEVEL        PY_RELEASE_LEVEL_FINAL
-#define PY_RELEASE_SERIAL       0
+#define PY_MICRO_VERSION        5
+#define PY_RELEASE_LEVEL        PY_RELEASE_LEVEL_GAMMA
+#define PY_RELEASE_SERIAL       1
 
 /* Version as a string */
-#define PY_VERSION              "3.14.4+"
+#define PY_VERSION              "3.14.5rc1"
 /*--end constants--*/
 
 
diff --git a/Lib/pydoc_data/module_docs.py b/Lib/pydoc_data/module_docs.py
index d65837838d1cab..e92fc6931b93f0 100644
--- a/Lib/pydoc_data/module_docs.py
+++ b/Lib/pydoc_data/module_docs.py
@@ -1,4 +1,4 @@
-# Autogenerated by Sphinx on Tue Apr  7 16:13:12 2026
+# Autogenerated by Sphinx on Mon May  4 18:31:32 2026
 # as part of the release process.
 
 module_docs = {
diff --git a/Misc/NEWS.d/3.14.5rc1.rst b/Misc/NEWS.d/3.14.5rc1.rst
new file mode 100644
index 00000000000000..1744c19d9864d2
--- /dev/null
+++ b/Misc/NEWS.d/3.14.5rc1.rst
@@ -0,0 +1,624 @@
+.. date: 2026-05-02-16-22-20
+.. gh-issue: 149254
+.. nonce: 9ozXB9
+.. release date: 2026-05-04
+.. section: Security
+
+Update Android and iOS installer to use OpenSSL 3.0.20.
+
+..
+
+.. date: 2026-04-26-17-49-58
+.. gh-issue: 149017
+.. nonce: EiVFPo
+.. section: Security
+
+Update bundled `libexpat <https://libexpat.github.io/>`_ to version 2.8.0.
+
+..
+
+.. date: 2026-04-21-13-46-30
+.. gh-issue: 90309
+.. nonce: srvj9q
+.. section: Security
+
+Base64-encode values when embedding cookies to JavaScript using the
+:meth:`http.cookies.BaseCookie.js_output` method to avoid injection and
+escaping.
+
+..
+
+.. date: 2026-04-20-15-31-37
+.. gh-issue: 148808
+.. nonce: _Z8JL0
+.. section: Security
+
+Added buffer boundary check when using ``nbytes`` parameter with
+:meth:`!asyncio.AbstractEventLoop.sock_recvfrom_into`. Only relevant for
+Windows and the :class:`asyncio.ProactorEventLoop`.
+
+..
+
+.. date: 2026-04-10-16-28-21
+.. gh-issue: 148395
+.. nonce: kfzm0G
+.. section: Security
+
+Fix a dangling input pointer in :class:`lzma.LZMADecompressor`,
+:class:`bz2.BZ2Decompressor`, and internal :class:`!zlib._ZlibDecompressor`
+when memory allocation fails with :exc:`MemoryError`, which could let a
+subsequent :meth:`!decompress` call read or write through a stale pointer to
+the already-released caller buffer.
+
+..
+
+.. date: 2026-03-31-09-15-51
+.. gh-issue: 148169
+.. nonce: EZJzz2
+.. section: Security
+
+A bypass in :mod:`webbrowser` allowed URLs prefixed with ``%action`` to pass
+the dash-prefix safety check.
+
+..
+
+.. date: 2026-03-29-12-51-33
+.. gh-issue: 146581
+.. nonce: 4vZfB0
+.. section: Security
+
+Fix vulnerability in :func:`shutil.unpack_archive` for ZIP files on Windows
+which allowed to write files outside of the destination tree if the patch in
+the archive contains a Windows drive prefix. Now such invalid paths will be
+skipped. Files containing ".." in the name (like "foo..bar") are no longer
+skipped.
+
+..
+
+.. date: 2026-03-25-00-51-03
+.. gh-issue: 146333
+.. nonce: LqdL__bn
+.. section: Security
+
+Fix quadratic backtracking in :class:`configparser.RawConfigParser` option
+parsing regexes (``OPTCRE`` and ``OPTCRE_NV``). A crafted configuration line
+with many whitespace characters could cause excessive CPU usage.
+
+..
+
+.. date: 2026-03-20-09-29-42
+.. gh-issue: 146211
+.. nonce: PQVbs7
+.. section: Security
+
+Reject CR/LF characters in tunnel request headers for the
+HTTPConnection.set_tunnel() method.
+
+..
+
+.. date: 2026-04-29-14-06-00
+.. gh-issue: 149122
+.. nonce: P8k2Lm
+.. section: Core and Builtins
+
+Fix a crash in optimized calls to :func:`all`, :func:`any`, :func:`tuple`,
+:func:`list`, and :func:`set` with an async generator expression argument
+(for example, ``tuple(await x for x in y)``). These calls now correctly
+raise ``TypeError`` instead of crashing.
+
+..
+
+.. date: 2026-04-22-14-55-18
+.. gh-issue: 113956
+.. nonce: 0VEXd6
+.. section: Core and Builtins
+
+Fix a data race in :func:`sys.intern` in the free-threaded build when
+interning a string owned by another thread. An interned copy owned by the
+current thread is used instead when it is not safe to immortalize the
+original.
+
+..
+
+.. date: 2026-04-21-14-36-44
+.. gh-issue: 148820
+.. nonce: XhOGhA
+.. section: Core and Builtins
+
+Fix a race in :c:type:`!_PyRawMutex` on the free-threaded build where a
+``Py_PARK_INTR`` return from ``_PySemaphore_Wait`` could let the waiter
+destroy its semaphore before the unlocking thread's ``_PySemaphore_Wakeup``
+completed, causing a fatal ``ReleaseSemaphore`` error.
+
+..
+
+.. date: 2026-04-17-20-37-02
+.. gh-issue: 148653
+.. nonce: nbbHMh
+.. section: Core and Builtins
+
+Forbid :mod:`marshalling <marshal>` recursive code objects and
+:class:`slice` objects which cannot be correctly unmarshalled.
+
+..
+
+.. date: 2026-04-17-11-30-00
+.. gh-issue: 142516
+.. nonce: GcGen315
+.. section: Core and Builtins
+
+Forward-port the generational cycle garbage collector to the default 3.14
+build, replacing the incremental collector while leaving the free-threaded
+collector unchanged.
+
+..
+
+.. date: 2026-04-12-17-27-28
+.. gh-issue: 148390
+.. nonce: MAhw7F
+.. section: Core and Builtins
+
+Fix an undefined behavior in :class:`memoryview` when using the native
+boolean format (``?``) in :meth:`~memoryview.cast`. Previously, on some
+common platforms, calling ``memoryview(b).cast("?").tolist()`` incorrectly
+returned ``[False]`` instead of ``[True]`` for any even byte *b*. Patch by
+Bénédikt Tran.
+
+..
+
+.. date: 2026-04-12-10-40-57
+.. gh-issue: 148418
+.. nonce: ggA1LZ
+.. section: Core and Builtins
+
+Fix a possible reference leak in a corrupted ``TYPE_CODE`` marshal stream.
+
+..
+
+.. date: 2026-04-11-17-28-52
+.. gh-issue: 148393
+.. nonce: lX6gwN
+.. section: Core and Builtins
+
+Fix data races between :c:func:`PyDict_Watch` / :c:func:`PyDict_Unwatch` and
+concurrent dict mutation in the :term:`free-threaded build`.
+
+..
+
+.. date: 2026-04-10-14-20-54
+.. gh-issue: 148284
+.. nonce: HKs-S_
+.. section: Core and Builtins
+
+Fix high stack consumption in Python's interpreter loop on Clang 22 by
+setting function limits for inlining when building with computed gotos.
+
+..
+
+.. date: 2026-04-09-14-18-33
+.. gh-issue: 148037
+.. nonce: aP3CSX
+.. section: Core and Builtins
+
+Remove critical section from :c:func:`!PyCode_Addr2Line` in free-threading.
+
+..
+
+.. date: 2026-04-07-20-37-23
+.. gh-issue: 148222
+.. nonce: uF4D4E
+.. section: Core and Builtins
+
+Fix vectorcall support in :class:`types.GenericAlias` when the underlying
+type does not support the vectorcall protocol. Fix possible leaks in
+:class:`types.GenericAlias` and :class:`types.UnionType` in case of memory
+error.
+
+..
+
+.. date: 2026-04-07-20-21-44
+.. gh-issue: 148208
+.. nonce: JAxpDU
+.. section: Core and Builtins
+
+Fix recursion depth leak in :c:func:`PyObject_Print`
+
+..
+
+.. date: 2026-04-07-07-21-30
+.. gh-issue: 137814
+.. nonce: 6yRTeu
+.. section: Core and Builtins
+
+Fix the ``__qualname__`` attribute of ``__annotate__`` functions on
+functions.
+
+..
+
+.. date: 2026-04-02-13-25-09
+.. gh-issue: 147998
+.. nonce: wnzkRT
+.. section: Core and Builtins
+
+Fixed a memory leak in interpreter helper calls so cleanup works when an
+operation falls across interpreter boundaries. Patch by Maurycy
+Pawłowski-Wieroński.
+
+..
+
+.. date: 2026-03-26-08-49-35
+.. gh-issue: 146455
+.. nonce: f54083a9
+.. section: Core and Builtins
+
+Fix O(N²) compile-time regression in constant folding after it was moved
+from AST to CFG optimizer.
+
+..
+
+.. date: 2026-05-02-12-03-48
+.. gh-issue: 149221
+.. nonce: __KOks
+.. section: Library
+
+Catch rare math domain error for :func:`random.binomialvariate`.
+
+..
+
+.. date: 2026-04-29-16-11-27
+.. gh-issue: 149117
+.. nonce: yEeTYd
+.. section: Library
+
+Fix :func:`runpy.run_module` and :func:`runpy.run_path` to set the
+:attr:`~ImportError.name` attribute on the :exc:`ImportError` they raise.
+
+..
+
+.. date: 2026-04-29-14-33-42
+.. gh-issue: 149148
+.. nonce: EaiYvk
+.. section: Library
+
+:mod:`ensurepip`: Upgrade bundled pip to 26.1. This version fixes the
+:cve:`2026-3219` vulnerability. Patch by Victor Stinner.
+
+..
+
+.. date: 2026-04-27-22-34-09
+.. gh-issue: 148093
+.. nonce: 9pWceM
+.. section: Library
+
+Fix an out-of-bounds read of one byte in :func:`binascii.a2b_uu`. Raise
+:exc:`binascii.Error`, instead of reading past the buffer end.
+
+..
+
+.. date: 2026-04-27-17-12-11
+.. gh-issue: 148914
+.. nonce: i5C3kW
+.. section: Library
+
+Fix memoization of in-band :class:`~pickle.PickleBuffer` in the Python
+implementation of :mod:`pickle`. Previously, identical
+:class:`!PickleBuffer`\ s did not preserve identity, and empty writable
+:class:`!PickleBuffer` memoized an empty bytearray object in place of
+``b''``, so the following references to ``b''`` were unpickled as an empty
+bytearray object.
+
+..
+
+.. date: 2026-04-23-21-47-49
+.. gh-issue: 148947
+.. nonce: W4V2lG
+.. section: Library
+
+Fix crash in :deco:`dataclasses.dataclass` with ``slots=True`` that occurred
+when a function found within the class had an empty ``__class__`` cell.
+
+..
+
+.. date: 2026-04-23-07-38-04
+.. gh-issue: 148680
+.. nonce: ___ePl
+.. section: Library
+
+``ForwardRef`` objects that contain internal names to represent known
+objects now show the ``type_repr`` of the known object rather than the
+internal ``__annotationlib_name_x__`` name when evaluated as strings.
+
+..
+
+.. date: 2026-04-20-18-29-21
+.. gh-issue: 148801
+.. nonce: ROeNqs
+.. section: Library
+
+:mod:`xml.etree.ElementTree`: Fix a crash in :meth:`Element.__deepcopy__
+<object.__deepcopy__>` on deeply nested trees.
+
+..
+
+.. date: 2026-04-18-21-39-15
+.. gh-issue: 148735
+.. nonce: siw6DG
+.. section: Library
+
+:mod:`xml.etree.ElementTree`: Fix a use-after-free in
+:meth:`Element.findtext <xml.etree.ElementTree.Element.findtext>` when the
+element tree is mutated concurrently during the search.
+
+..
+
+.. date: 2026-04-18-17-37-13
+.. gh-issue: 148740
+.. nonce: sYnFi0
+.. section: Library
+
+Fix usage for :mod:`uuid` command-line interface to support a custom
+namespace be provided for uuid3 and uuid5.
+
+..
+
+.. date: 2026-04-16-13-30-00
+.. gh-issue: 148651
+.. nonce: ZsTdLk
+.. section: Library
+
+Fix reference leak in :class:`compression.zstd.ZstdDecompressor` when an
+invalid option key is passed.
+
+..
+
+.. date: 2026-04-15-11-00-39
+.. gh-issue: 146553
+.. nonce: VGOsoP
+.. section: Library
+
+Fix infinite loop in :func:`typing.get_type_hints` when ``__wrapped__``
+forms a cycle. Patch by Shamil Abdulaev.
+
+..
+
+.. date: 2026-04-14-09-04-35
+.. gh-issue: 148508
+.. nonce: -GiXml
+.. section: Library
+
+An intermittent timing error when running SSL tests on iOS has been
+resolved.
+
+..
+
+.. date: 2026-04-13-15-59-44
+.. gh-issue: 148518
+.. nonce: RQdvsu
+.. section: Library
+
+If an email containing an address header that ended in an open double quote
+was parsed with a non-``compat32`` policy, accessing the ``username``
+attribute of the mailbox accessed through that header object would result in
+an ``IndexError``. It now correctly returns an empty string as the result.
+
+..
+
+.. date: 2026-04-13-06-22-27
+.. gh-issue: 148464
+.. nonce: Bj_NZy
+.. section: Library
+
+Add missing ``__ctype_le/be__`` attributes for
+:class:`~ctypes.c_float_complex` and :class:`~ctypes.c_double_complex`.
+Patch by Sergey B Kirpichev.
+
+..
+
+.. date: 2026-04-12-16-40-11
+.. gh-issue: 148370
+.. nonce: 0Li2EK
+.. section: Library
+
+:mod:`configparser`: prevent quadratic behavior when a
+:exc:`~configparser.ParsingError` is raised after a parser fails to parse
+multiple lines. Patch by Bénédikt Tran.
+
+..
+
+.. date: 2026-04-09-12-42-42
+.. gh-issue: 148254
+.. nonce: Xt7vKs
+.. section: Library
+
+Use singular "sec" instead of "secs" in :mod:`timeit` verbose output for
+consistency with other time units.
+
+..
+
+.. date: 2026-04-07-14-13-40
+.. gh-issue: 148192
+.. nonce: 34AUYQ
+.. section: Library
+
+``email.generator.Generator._make_boundary`` could fail to detect a
+duplicate boundary string if linesep was not \n. It now correctly detects
+boundary strings when linesep is \r\n as well.
+
+..
+
+.. date: 2026-03-22-23-42-22
+.. gh-issue: 146313
+.. nonce: RtDeAd
+.. section: Library
+
+Fix a deadlock in :mod:`multiprocessing`'s resource tracker where the parent
+process could hang indefinitely in :func:`os.waitpid` during interpreter
+shutdown if a child created via :func:`os.fork` still held the resource
+tracker's pipe open.
+
+..
+
+.. date: 2026-03-11-15-09-52
+.. gh-issue: 145831
+.. nonce: _sW94w
+.. section: Library
+
+Fix :func:`!email.quoprimime.decode` leaving a stray ``\r`` when
+``eol='\r\n'`` by stripping the full *eol* string instead of one character.
+
+..
+
+.. date: 2026-02-22-00-00-00
+.. gh-issue: 145105
+.. nonce: csv-reader-reentrant
+.. section: Library
+
+Fix crash in :mod:`csv` reader when iterating with a re-entrant iterator
+that calls :func:`next` on the same reader from within ``__next__``.
+
+..
+
+.. date: 2026-01-19-21-23-18
+.. gh-issue: 105936
+.. nonce: dGrzjM
+.. section: Library
+
+Attempting to mutate non-field attributes of :mod:`dataclasses` with both
+*frozen* and *slots* being ``True`` now raises
+:class:`~dataclasses.FrozenInstanceError` instead of :class:`TypeError`.
+Their non-dataclass subclasses can now freely mutate non-field attributes,
+and the original non-slotted class can be garbage collected.
+
+..
+
+.. date: 2025-10-18-12-13-39
+.. gh-issue: 140287
+.. nonce: 49iU-4
+.. section: Library
+
+The :mod:`asyncio` REPL now handles exceptions when executing
+:envvar:`PYTHONSTARTUP` scripts. Patch by Bartosz Sławecki.
+
+..
+
+.. date: 2025-04-17-15-26-35
+.. gh-issue: 132631
+.. nonce: IDFZfb
+.. section: Library
+
+Fix "I/O operation on closed file" when parsing JSON Lines file with
+:mod:`JSON CLI <json.tool>`.
+
+..
+
+.. date: 2024-02-10-21-25-22
+.. gh-issue: 70039
+.. nonce: 6wvcAP
+.. section: Library
+
+Fixed bug where :meth:`smtplib.SMTP.starttls` could fail if
+:meth:`smtplib.SMTP.connect` is called explicitly rather than implicitly.
+
+..
+
+.. date: 2023-09-08-13-10-32
+.. gh-issue: 83281
+.. nonce: 2Plpcj
+.. section: Library
+
+:mod:`email`: improve handling trailing garbage in address lists to avoid
+throwing AttributeError in certain edge cases
+
+..
+
+.. date: 2026-04-17-02-28-55
+.. gh-issue: 148663
+.. nonce: MHIbRB
+.. section: Documentation
+
+Document that :class:`calendar.IllegalMonthError` is a subclass of both
+:exc:`ValueError` and :exc:`IndexError` since Python 3.12.
+
+..
+
+.. date: 2026-04-02-07-20-00
+.. gh-issue: 146646
+.. nonce: GlobDoc1
+.. section: Documentation
+
+Document that :func:`glob.glob`, :func:`glob.iglob`,
+:meth:`pathlib.Path.glob`, and :meth:`pathlib.Path.rglob` silently suppress
+:exc:`OSError` exceptions raised from scanning the filesystem.
+
+..
+
+.. date: 2026-05-04-06-03-50
+.. gh-issue: 149351
+.. nonce: hN4sF0
+.. section: Build
+
+Avoid possible broken macOS framework install names when DESTDIR is
+specified during builds.
+
+..
+
+.. date: 2026-04-30-08-43-47
+.. gh-issue: 146475
+.. nonce: 1cL4hX
+.. section: Build
+
+Block Apple Clang from being used to build the JIT as it ships without
+required LLVM tools.
+
+..
+
+.. date: 2026-04-14-15-20-29
+.. gh-issue: 148535
+.. nonce: JjKiaa
+.. section: Build
+
+No longer use the ``gcc -fprofile-update=atomic`` flag on i686. The flag has
+been added to fix a random GCC internal error on PGO build (:gh:`145801`)
+caused by corruption of profile data (.gcda files). The problem is that it
+makes the PGO build way slower (up to 47x slower) on i686. Since the GCC
+internal error was not seen on i686 so far, don't use
+``-fprofile-update=atomic`` on i686 anymore. Patch by Victor Stinner.
+
+..
+
+.. date: 2026-03-21-18-51-31
+.. gh-issue: 146264
+.. nonce: Q9Ej4m
+.. section: Build
+
+Fix static module builds on non-WASI targets by linking HACL dependencies as
+static libraries when ``MODULE_BUILDTYPE=static``, preventing duplicate
+``_Py_LibHacl_*`` symbol errors at link time.
+
+..
+
+.. date: 2026-05-03-14-07-51
+.. gh-issue: 149254
+.. nonce: ENtMYD
+.. section: Windows
+
+Updated bundled version of OpenSSL to 3.0.20.
+
+..
+
+.. date: 2026-03-27-22-06-10
+.. gh-issue: 146458
+.. nonce: fYj0UQ
+.. section: Windows
+
+Fix incorrect REPL height and width tracking on console window resize on
+Windows.
+
+..
+
+.. date: 2026-05-01-19-38-16
+.. gh-issue: 149254
+.. nonce: enO7uj
+.. section: macOS
+
+Update macOS installer to use OpenSSL 3.0.20.
diff --git 
a/Misc/NEWS.d/next/Build/2026-03-21-18-51-31.gh-issue-146264.Q9Ej4m.rst 
b/Misc/NEWS.d/next/Build/2026-03-21-18-51-31.gh-issue-146264.Q9Ej4m.rst
deleted file mode 100644
index 1fdafe560432a6..00000000000000
--- a/Misc/NEWS.d/next/Build/2026-03-21-18-51-31.gh-issue-146264.Q9Ej4m.rst
+++ /dev/null
@@ -1,3 +0,0 @@
-Fix static module builds on non-WASI targets by linking HACL dependencies as
-static libraries when ``MODULE_BUILDTYPE=static``, preventing duplicate
-``_Py_LibHacl_*`` symbol errors at link time.
diff --git 
a/Misc/NEWS.d/next/Build/2026-04-14-15-20-29.gh-issue-148535.JjKiaa.rst 
b/Misc/NEWS.d/next/Build/2026-04-14-15-20-29.gh-issue-148535.JjKiaa.rst
deleted file mode 100644
index 39f37acb14e098..00000000000000
--- a/Misc/NEWS.d/next/Build/2026-04-14-15-20-29.gh-issue-148535.JjKiaa.rst
+++ /dev/null
@@ -1,6 +0,0 @@
-No longer use the ``gcc -fprofile-update=atomic`` flag on i686. The flag has
-been added to fix a random GCC internal error on PGO build (:gh:`145801`)
-caused by corruption of profile data (.gcda files). The problem is that it
-makes the PGO build way slower (up to 47x slower) on i686. Since the GCC
-internal error was not seen on i686 so far, don't use
-``-fprofile-update=atomic`` on i686 anymore. Patch by Victor Stinner.
diff --git 
a/Misc/NEWS.d/next/Build/2026-04-30-08-43-47.gh-issue-146475.1cL4hX.rst 
b/Misc/NEWS.d/next/Build/2026-04-30-08-43-47.gh-issue-146475.1cL4hX.rst
deleted file mode 100644
index 225c659393fac5..00000000000000
--- a/Misc/NEWS.d/next/Build/2026-04-30-08-43-47.gh-issue-146475.1cL4hX.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Block Apple Clang from being used to build the JIT as it ships without
-required LLVM tools.
diff --git 
a/Misc/NEWS.d/next/Build/2026-05-04-06-03-50.gh-issue-149351.hN4sF0.rst 
b/Misc/NEWS.d/next/Build/2026-05-04-06-03-50.gh-issue-149351.hN4sF0.rst
deleted file mode 100644
index 792c8d394eccb2..00000000000000
--- a/Misc/NEWS.d/next/Build/2026-05-04-06-03-50.gh-issue-149351.hN4sF0.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Avoid possible broken macOS framework install names when DESTDIR is
-specified during builds.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-03-26-08-49-35.gh-issue-146455.f54083a9.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-03-26-08-49-35.gh-issue-146455.f54083a9.rst
deleted file mode 100644
index 4d7537f2529da6..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-03-26-08-49-35.gh-issue-146455.f54083a9.rst
+++ /dev/null
@@ -1 +0,0 @@
-Fix O(N²) compile-time regression in constant folding after it was moved from 
AST to CFG optimizer.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-02-13-25-09.gh-issue-147998.wnzkRT.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-02-13-25-09.gh-issue-147998.wnzkRT.rst
deleted file mode 100644
index e83d9929eae5e0..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-02-13-25-09.gh-issue-147998.wnzkRT.rst
+++ /dev/null
@@ -1,3 +0,0 @@
-Fixed a memory leak in interpreter helper calls so cleanup works when an
-operation falls across interpreter boundaries. Patch by Maurycy
-Pawłowski-Wieroński.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-07-21-30.gh-issue-137814.6yRTeu.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-07-21-30.gh-issue-137814.6yRTeu.rst
deleted file mode 100644
index 83561312deeb02..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-07-21-30.gh-issue-137814.6yRTeu.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Fix the ``__qualname__`` attribute of ``__annotate__`` functions on
-functions.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-20-21-44.gh-issue-148208.JAxpDU.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-20-21-44.gh-issue-148208.JAxpDU.rst
deleted file mode 100644
index b8ae19f5877a7d..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-20-21-44.gh-issue-148208.JAxpDU.rst
+++ /dev/null
@@ -1 +0,0 @@
-Fix recursion depth leak in :c:func:`PyObject_Print`
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-20-37-23.gh-issue-148222.uF4D4E.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-20-37-23.gh-issue-148222.uF4D4E.rst
deleted file mode 100644
index 2c273fc4daba3d..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-07-20-37-23.gh-issue-148222.uF4D4E.rst
+++ /dev/null
@@ -1 +0,0 @@
-Fix vectorcall support in :class:`types.GenericAlias` when the underlying type 
does not support the vectorcall protocol. Fix possible leaks in 
:class:`types.GenericAlias` and :class:`types.UnionType` in case of memory 
error.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-09-14-18-33.gh-issue-148037.aP3CSX.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-09-14-18-33.gh-issue-148037.aP3CSX.rst
deleted file mode 100644
index b0cef595129817..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-09-14-18-33.gh-issue-148037.aP3CSX.rst
+++ /dev/null
@@ -1 +0,0 @@
-Remove critical section from :c:func:`!PyCode_Addr2Line` in free-threading.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-10-14-20-54.gh-issue-148284.HKs-S_.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-10-14-20-54.gh-issue-148284.HKs-S_.rst
deleted file mode 100644
index a74f6c1a61affd..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-10-14-20-54.gh-issue-148284.HKs-S_.rst
+++ /dev/null
@@ -1 +0,0 @@
-Fix high stack consumption in Python's interpreter loop on Clang 22 by setting 
function limits for inlining when building with computed gotos.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-11-17-28-52.gh-issue-148393.lX6gwN.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-11-17-28-52.gh-issue-148393.lX6gwN.rst
deleted file mode 100644
index 33c4b75bfb944c..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-11-17-28-52.gh-issue-148393.lX6gwN.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Fix data races between :c:func:`PyDict_Watch` / :c:func:`PyDict_Unwatch`
-and concurrent dict mutation in the :term:`free-threaded build`.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-12-10-40-57.gh-issue-148418.ggA1LZ.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-12-10-40-57.gh-issue-148418.ggA1LZ.rst
deleted file mode 100644
index 793858be7814c1..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-12-10-40-57.gh-issue-148418.ggA1LZ.rst
+++ /dev/null
@@ -1 +0,0 @@
-Fix a possible reference leak in a corrupted ``TYPE_CODE`` marshal stream.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-12-17-27-28.gh-issue-148390.MAhw7F.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-12-17-27-28.gh-issue-148390.MAhw7F.rst
deleted file mode 100644
index 881964673307cc..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-12-17-27-28.gh-issue-148390.MAhw7F.rst
+++ /dev/null
@@ -1,5 +0,0 @@
-Fix an undefined behavior in :class:`memoryview` when using the native
-boolean format (``?``) in :meth:`~memoryview.cast`. Previously, on some
-common platforms, calling ``memoryview(b).cast("?").tolist()`` incorrectly
-returned ``[False]`` instead of ``[True]`` for any even byte *b*.
-Patch by Bénédikt Tran.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-17-11-30-00.gh-issue-142516.GcGen315.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-17-11-30-00.gh-issue-142516.GcGen315.rst
deleted file mode 100644
index ed21c8b26a8742..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-17-11-30-00.gh-issue-142516.GcGen315.rst
+++ /dev/null
@@ -1 +0,0 @@
-Forward-port the generational cycle garbage collector to the default 3.14 
build, replacing the incremental collector while leaving the free-threaded 
collector unchanged.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-17-20-37-02.gh-issue-148653.nbbHMh.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-17-20-37-02.gh-issue-148653.nbbHMh.rst
deleted file mode 100644
index 0f8bdd1ff7ee2a..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-17-20-37-02.gh-issue-148653.nbbHMh.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Forbid :mod:`marshalling <marshal>` recursive code objects and :class:`slice`
-objects which cannot be correctly unmarshalled.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-21-14-36-44.gh-issue-148820.XhOGhA.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-21-14-36-44.gh-issue-148820.XhOGhA.rst
deleted file mode 100644
index 392becaffb73cf..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-21-14-36-44.gh-issue-148820.XhOGhA.rst
+++ /dev/null
@@ -1,5 +0,0 @@
-Fix a race in :c:type:`!_PyRawMutex` on the free-threaded build where a
-``Py_PARK_INTR`` return from ``_PySemaphore_Wait`` could let the waiter
-destroy its semaphore before the unlocking thread's
-``_PySemaphore_Wakeup`` completed, causing a fatal ``ReleaseSemaphore``
-error.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-22-14-55-18.gh-issue-113956.0VEXd6.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-22-14-55-18.gh-issue-113956.0VEXd6.rst
deleted file mode 100644
index 54c04bbc28d416..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-22-14-55-18.gh-issue-113956.0VEXd6.rst
+++ /dev/null
@@ -1,4 +0,0 @@
-Fix a data race in :func:`sys.intern` in the free-threaded build when
-interning a string owned by another thread. An interned copy owned by the
-current thread is used instead when it is not safe to immortalize the
-original.
diff --git 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-29-14-06-00.gh-issue-149122.P8k2Lm.rst
 
b/Misc/NEWS.d/next/Core_and_Builtins/2026-04-29-14-06-00.gh-issue-149122.P8k2Lm.rst
deleted file mode 100644
index f34b6ea857a06c..00000000000000
--- 
a/Misc/NEWS.d/next/Core_and_Builtins/2026-04-29-14-06-00.gh-issue-149122.P8k2Lm.rst
+++ /dev/null
@@ -1,4 +0,0 @@
-Fix a crash in optimized calls to :func:`all`, :func:`any`, :func:`tuple`,
-:func:`list`, and :func:`set` with an async generator expression argument
-(for example, ``tuple(await x for x in y)``). These calls now correctly raise
-``TypeError`` instead of crashing.
diff --git 
a/Misc/NEWS.d/next/Documentation/2026-04-02-07-20-00.gh-issue-146646.GlobDoc1.rst
 
b/Misc/NEWS.d/next/Documentation/2026-04-02-07-20-00.gh-issue-146646.GlobDoc1.rst
deleted file mode 100644
index 4e89270442a33b..00000000000000
--- 
a/Misc/NEWS.d/next/Documentation/2026-04-02-07-20-00.gh-issue-146646.GlobDoc1.rst
+++ /dev/null
@@ -1,3 +0,0 @@
-Document that :func:`glob.glob`, :func:`glob.iglob`,
-:meth:`pathlib.Path.glob`, and :meth:`pathlib.Path.rglob` silently suppress
-:exc:`OSError` exceptions raised from scanning the filesystem.
diff --git 
a/Misc/NEWS.d/next/Documentation/2026-04-17-02-28-55.gh-issue-148663.MHIbRB.rst 
b/Misc/NEWS.d/next/Documentation/2026-04-17-02-28-55.gh-issue-148663.MHIbRB.rst
deleted file mode 100644
index 0fbe5a699ef0ad..00000000000000
--- 
a/Misc/NEWS.d/next/Documentation/2026-04-17-02-28-55.gh-issue-148663.MHIbRB.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Document that :class:`calendar.IllegalMonthError` is a subclass of both
-:exc:`ValueError` and :exc:`IndexError` since Python 3.12.
diff --git 
a/Misc/NEWS.d/next/Library/2023-09-08-13-10-32.gh-issue-83281.2Plpcj.rst 
b/Misc/NEWS.d/next/Library/2023-09-08-13-10-32.gh-issue-83281.2Plpcj.rst
deleted file mode 100644
index cf2ae770bd1940..00000000000000
--- a/Misc/NEWS.d/next/Library/2023-09-08-13-10-32.gh-issue-83281.2Plpcj.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-:mod:`email`: improve handling trailing garbage in address lists to avoid 
throwing
-AttributeError in certain edge cases
diff --git 
a/Misc/NEWS.d/next/Library/2024-02-10-21-25-22.gh-issue-70039.6wvcAP.rst 
b/Misc/NEWS.d/next/Library/2024-02-10-21-25-22.gh-issue-70039.6wvcAP.rst
deleted file mode 100644
index 8bb2cd188e89fa..00000000000000
--- a/Misc/NEWS.d/next/Library/2024-02-10-21-25-22.gh-issue-70039.6wvcAP.rst
+++ /dev/null
@@ -1 +0,0 @@
-Fixed bug where :meth:`smtplib.SMTP.starttls` could fail if 
:meth:`smtplib.SMTP.connect` is called explicitly rather than implicitly.
diff --git 
a/Misc/NEWS.d/next/Library/2025-04-17-15-26-35.gh-issue-132631.IDFZfb.rst 
b/Misc/NEWS.d/next/Library/2025-04-17-15-26-35.gh-issue-132631.IDFZfb.rst
deleted file mode 100644
index 9cc1d5a389c085..00000000000000
--- a/Misc/NEWS.d/next/Library/2025-04-17-15-26-35.gh-issue-132631.IDFZfb.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Fix "I/O operation on closed file" when parsing JSON Lines file with
-:mod:`JSON CLI <json.tool>`.
diff --git 
a/Misc/NEWS.d/next/Library/2025-10-18-12-13-39.gh-issue-140287.49iU-4.rst 
b/Misc/NEWS.d/next/Library/2025-10-18-12-13-39.gh-issue-140287.49iU-4.rst
deleted file mode 100644
index 09643956d98093..00000000000000
--- a/Misc/NEWS.d/next/Library/2025-10-18-12-13-39.gh-issue-140287.49iU-4.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-The :mod:`asyncio` REPL now handles exceptions when executing 
:envvar:`PYTHONSTARTUP` scripts.
-Patch by Bartosz Sławecki.
diff --git 
a/Misc/NEWS.d/next/Library/2026-01-19-21-23-18.gh-issue-105936.dGrzjM.rst 
b/Misc/NEWS.d/next/Library/2026-01-19-21-23-18.gh-issue-105936.dGrzjM.rst
deleted file mode 100644
index c1d3ec806e597c..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-01-19-21-23-18.gh-issue-105936.dGrzjM.rst
+++ /dev/null
@@ -1,5 +0,0 @@
-Attempting to mutate non-field attributes of :mod:`dataclasses`
-with both *frozen* and *slots* being ``True`` now raises
-:class:`~dataclasses.FrozenInstanceError` instead of :class:`TypeError`.
-Their non-dataclass subclasses can now freely mutate non-field attributes,
-and the original non-slotted class can be garbage collected.
diff --git 
a/Misc/NEWS.d/next/Library/2026-02-22-00-00-00.gh-issue-145105.csv-reader-reentrant.rst
 
b/Misc/NEWS.d/next/Library/2026-02-22-00-00-00.gh-issue-145105.csv-reader-reentrant.rst
deleted file mode 100644
index 1c2e06c86f6588..00000000000000
--- 
a/Misc/NEWS.d/next/Library/2026-02-22-00-00-00.gh-issue-145105.csv-reader-reentrant.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Fix crash in :mod:`csv` reader when iterating with a re-entrant iterator
-that calls :func:`next` on the same reader from within ``__next__``.
diff --git 
a/Misc/NEWS.d/next/Library/2026-03-11-15-09-52.gh-issue-145831._sW94w.rst 
b/Misc/NEWS.d/next/Library/2026-03-11-15-09-52.gh-issue-145831._sW94w.rst
deleted file mode 100644
index 454b62bc0db95f..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-03-11-15-09-52.gh-issue-145831._sW94w.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Fix :func:`!email.quoprimime.decode` leaving a stray ``\r`` when
-``eol='\r\n'`` by stripping the full *eol* string instead of one character.
diff --git 
a/Misc/NEWS.d/next/Library/2026-03-22-23-42-22.gh-issue-146313.RtDeAd.rst 
b/Misc/NEWS.d/next/Library/2026-03-22-23-42-22.gh-issue-146313.RtDeAd.rst
deleted file mode 100644
index 1beea3694c422e..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-03-22-23-42-22.gh-issue-146313.RtDeAd.rst
+++ /dev/null
@@ -1,4 +0,0 @@
-Fix a deadlock in :mod:`multiprocessing`'s resource tracker
-where the parent process could hang indefinitely in :func:`os.waitpid`
-during interpreter shutdown if a child created via :func:`os.fork` still
-held the resource tracker's pipe open.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-07-14-13-40.gh-issue-148192.34AUYQ.rst 
b/Misc/NEWS.d/next/Library/2026-04-07-14-13-40.gh-issue-148192.34AUYQ.rst
deleted file mode 100644
index 87a568b50c17c3..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-07-14-13-40.gh-issue-148192.34AUYQ.rst
+++ /dev/null
@@ -1,3 +0,0 @@
-``email.generator.Generator._make_boundary`` could fail to detect a duplicate
-boundary string if linesep was not \n. It now correctly detects boundary
-strings when linesep is \r\n as well.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-09-12-42-42.gh-issue-148254.Xt7vKs.rst 
b/Misc/NEWS.d/next/Library/2026-04-09-12-42-42.gh-issue-148254.Xt7vKs.rst
deleted file mode 100644
index 818310c31b9de6..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-09-12-42-42.gh-issue-148254.Xt7vKs.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Use singular "sec" instead of "secs" in :mod:`timeit` verbose output for
-consistency with other time units.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-12-16-40-11.gh-issue-148370.0Li2EK.rst 
b/Misc/NEWS.d/next/Library/2026-04-12-16-40-11.gh-issue-148370.0Li2EK.rst
deleted file mode 100644
index 3bb662350796f6..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-12-16-40-11.gh-issue-148370.0Li2EK.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-:mod:`configparser`: prevent quadratic behavior when a 
:exc:`~configparser.ParsingError`
-is raised after a parser fails to parse multiple lines. Patch by Bénédikt Tran.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-13-06-22-27.gh-issue-148464.Bj_NZy.rst 
b/Misc/NEWS.d/next/Library/2026-04-13-06-22-27.gh-issue-148464.Bj_NZy.rst
deleted file mode 100644
index 85b99531d033b1..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-13-06-22-27.gh-issue-148464.Bj_NZy.rst
+++ /dev/null
@@ -1,3 +0,0 @@
-Add missing ``__ctype_le/be__`` attributes for
-:class:`~ctypes.c_float_complex` and :class:`~ctypes.c_double_complex`. Patch
-by Sergey B Kirpichev.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-13-15-59-44.gh-issue-148518.RQdvsu.rst 
b/Misc/NEWS.d/next/Library/2026-04-13-15-59-44.gh-issue-148518.RQdvsu.rst
deleted file mode 100644
index 994e4ad7446670..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-13-15-59-44.gh-issue-148518.RQdvsu.rst
+++ /dev/null
@@ -1,4 +0,0 @@
-If an email containing an address header that ended in an open double quote
-was parsed with a non-``compat32`` policy, accessing the ``username`` attribute
-of the mailbox accessed through that header object would result in an
-``IndexError``. It now correctly returns an empty string as the result.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-14-09-04-35.gh-issue-148508.-GiXml.rst 
b/Misc/NEWS.d/next/Library/2026-04-14-09-04-35.gh-issue-148508.-GiXml.rst
deleted file mode 100644
index 7995dec397f7b7..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-14-09-04-35.gh-issue-148508.-GiXml.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-An intermittent timing error when running SSL tests on iOS has been
-resolved.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-15-11-00-39.gh-issue-146553.VGOsoP.rst 
b/Misc/NEWS.d/next/Library/2026-04-15-11-00-39.gh-issue-146553.VGOsoP.rst
deleted file mode 100644
index 44216318d474a9..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-15-11-00-39.gh-issue-146553.VGOsoP.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Fix infinite loop in :func:`typing.get_type_hints` when ``__wrapped__``
-forms a cycle. Patch by Shamil Abdulaev.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-16-13-30-00.gh-issue-148651.ZsTdLk.rst 
b/Misc/NEWS.d/next/Library/2026-04-16-13-30-00.gh-issue-148651.ZsTdLk.rst
deleted file mode 100644
index b69f94a17663dc..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-16-13-30-00.gh-issue-148651.ZsTdLk.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Fix reference leak in :class:`compression.zstd.ZstdDecompressor` when an
-invalid option key is passed.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-18-17-37-13.gh-issue-148740.sYnFi0.rst 
b/Misc/NEWS.d/next/Library/2026-04-18-17-37-13.gh-issue-148740.sYnFi0.rst
deleted file mode 100644
index 7e49cedda7beb2..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-18-17-37-13.gh-issue-148740.sYnFi0.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Fix usage for :mod:`uuid` command-line interface to support a custom namespace 
be
-provided for uuid3 and uuid5.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-18-21-39-15.gh-issue-148735.siw6DG.rst 
b/Misc/NEWS.d/next/Library/2026-04-18-21-39-15.gh-issue-148735.siw6DG.rst
deleted file mode 100644
index db5e94c0ccac50..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-18-21-39-15.gh-issue-148735.siw6DG.rst
+++ /dev/null
@@ -1,3 +0,0 @@
-:mod:`xml.etree.ElementTree`: Fix a use-after-free in
-:meth:`Element.findtext <xml.etree.ElementTree.Element.findtext>` when the
-element tree is mutated concurrently during the search.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-20-18-29-21.gh-issue-148801.ROeNqs.rst 
b/Misc/NEWS.d/next/Library/2026-04-20-18-29-21.gh-issue-148801.ROeNqs.rst
deleted file mode 100644
index 6fcd30e8f057b9..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-20-18-29-21.gh-issue-148801.ROeNqs.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-:mod:`xml.etree.ElementTree`: Fix a crash in :meth:`Element.__deepcopy__
-<object.__deepcopy__>` on deeply nested trees.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-23-07-38-04.gh-issue-148680.___ePl.rst 
b/Misc/NEWS.d/next/Library/2026-04-23-07-38-04.gh-issue-148680.___ePl.rst
deleted file mode 100644
index d3790079545a07..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-23-07-38-04.gh-issue-148680.___ePl.rst
+++ /dev/null
@@ -1 +0,0 @@
-``ForwardRef`` objects that contain internal names to represent known objects 
now show the ``type_repr`` of the known object rather than the internal 
``__annotationlib_name_x__`` name when evaluated as strings.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-23-21-47-49.gh-issue-148947.W4V2lG.rst 
b/Misc/NEWS.d/next/Library/2026-04-23-21-47-49.gh-issue-148947.W4V2lG.rst
deleted file mode 100644
index f9783266f5cc42..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-23-21-47-49.gh-issue-148947.W4V2lG.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Fix crash in :deco:`dataclasses.dataclass` with ``slots=True`` that occurred
-when a function found within the class had an empty ``__class__`` cell.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-27-17-12-11.gh-issue-148914.i5C3kW.rst 
b/Misc/NEWS.d/next/Library/2026-04-27-17-12-11.gh-issue-148914.i5C3kW.rst
deleted file mode 100644
index 8348aad0d892c3..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-27-17-12-11.gh-issue-148914.i5C3kW.rst
+++ /dev/null
@@ -1,6 +0,0 @@
-Fix memoization of in-band :class:`~pickle.PickleBuffer` in the Python
-implementation of :mod:`pickle`. Previously, identical
-:class:`!PickleBuffer`\ s did not preserve identity, and empty writable
-:class:`!PickleBuffer` memoized an empty bytearray object in place of
-``b''``, so the following references to ``b''`` were unpickled as an empty
-bytearray object.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-27-22-34-09.gh-issue-148093.9pWceM.rst 
b/Misc/NEWS.d/next/Library/2026-04-27-22-34-09.gh-issue-148093.9pWceM.rst
deleted file mode 100644
index 9418044201f8bd..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-27-22-34-09.gh-issue-148093.9pWceM.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Fix an out-of-bounds read of one byte in :func:`binascii.a2b_uu`. Raise
-:exc:`binascii.Error`, instead of reading past the buffer end.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-29-14-33-42.gh-issue-149148.EaiYvk.rst 
b/Misc/NEWS.d/next/Library/2026-04-29-14-33-42.gh-issue-149148.EaiYvk.rst
deleted file mode 100644
index 06186773474fb9..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-29-14-33-42.gh-issue-149148.EaiYvk.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-:mod:`ensurepip`: Upgrade bundled pip to 26.1. This version fixes
-the :cve:`2026-3219` vulnerability. Patch by Victor Stinner.
diff --git 
a/Misc/NEWS.d/next/Library/2026-04-29-16-11-27.gh-issue-149117.yEeTYd.rst 
b/Misc/NEWS.d/next/Library/2026-04-29-16-11-27.gh-issue-149117.yEeTYd.rst
deleted file mode 100644
index 41223e90ed0b0e..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-04-29-16-11-27.gh-issue-149117.yEeTYd.rst
+++ /dev/null
@@ -1,3 +0,0 @@
-Fix :func:`runpy.run_module` and :func:`runpy.run_path` to set the
-:attr:`~ImportError.name` attribute on the :exc:`ImportError` they
-raise.
diff --git 
a/Misc/NEWS.d/next/Library/2026-05-02-12-03-48.gh-issue-149221.__KOks.rst 
b/Misc/NEWS.d/next/Library/2026-05-02-12-03-48.gh-issue-149221.__KOks.rst
deleted file mode 100644
index fab2b0f6a23489..00000000000000
--- a/Misc/NEWS.d/next/Library/2026-05-02-12-03-48.gh-issue-149221.__KOks.rst
+++ /dev/null
@@ -1 +0,0 @@
-Catch rare math domain error for :func:`random.binomialvariate`.
diff --git 
a/Misc/NEWS.d/next/Security/2026-03-20-09-29-42.gh-issue-146211.PQVbs7.rst 
b/Misc/NEWS.d/next/Security/2026-03-20-09-29-42.gh-issue-146211.PQVbs7.rst
deleted file mode 100644
index 4993633b8ebebb..00000000000000
--- a/Misc/NEWS.d/next/Security/2026-03-20-09-29-42.gh-issue-146211.PQVbs7.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-Reject CR/LF characters in tunnel request headers for the
-HTTPConnection.set_tunnel() method.
diff --git 
a/Misc/NEWS.d/next/Security/2026-03-25-00-51-03.gh-issue-146333.LqdL__bn.rst 
b/Misc/NEWS.d/next/Security/2026-03-25-00-51-03.gh-issue-146333.LqdL__bn.rst
deleted file mode 100644
index 96d86ecc0a0fb3..00000000000000
--- a/Misc/NEWS.d/next/Security/2026-03-25-00-51-03.gh-issue-146333.LqdL__bn.rst
+++ /dev/null
@@ -1,3 +0,0 @@
-Fix quadratic backtracking in :class:`configparser.RawConfigParser` option
-parsing regexes (``OPTCRE`` and ``OPTCRE_NV``). A crafted configuration line
-with many whitespace characters could cause excessive CPU usage.
diff --git 
a/Misc/NEWS.d/next/Security/2026-03-29-12-51-33.gh-issue-146581.4vZfB0.rst 
b/Misc/NEWS.d/next/Security/2026-03-29-12-51-33.gh-issue-146581.4vZfB0.rst
deleted file mode 100644
index 98e65549d79016..00000000000000
--- a/Misc/NEWS.d/next/Security/2026-03-29-12-51-33.gh-issue-146581.4vZfB0.rst
+++ /dev/null
@@ -1,5 +0,0 @@
-Fix vulnerability in :func:`shutil.unpack_archive` for ZIP files on Windows
-which allowed to write files outside of the destination tree if the patch in
-the archive contains a Windows drive prefix. Now such invalid paths will be
-skipped. Files containing ".." in the name (like "foo..bar") are no longer
-skipped.
diff --git 
a/Misc/NEWS.d/next/Security/2026-03-31-09-15-51.gh-issue-148169.EZJzz2.rst 
b/Misc/NEWS.d/next/Security/2026-03-31-09-15-51.gh-issue-148169.EZJzz2.rst
deleted file mode 100644
index 45cdeebe1b6d64..00000000000000
--- a/Misc/NEWS.d/next/Security/2026-03-31-09-15-51.gh-issue-148169.EZJzz2.rst
+++ /dev/null
@@ -1,2 +0,0 @@
-A bypass in :mod:`webbrowser` allowed URLs prefixed with ``%action`` to pass
-the dash-prefix safety check.
diff --git 
a/Misc/NEWS.d/next/Security/2026-04-10-16-28-21.gh-issue-148395.kfzm0G.rst 
b/Misc/NEWS.d/next/Security/2026-04-10-16-28-21.gh-issue-148395.kfzm0G.rst
deleted file mode 100644
index 9502189ab199c1..00000000000000
--- a/Misc/NEWS.d/next/Security/2026-04-10-16-28-21.gh-issue-148395.kfzm0G.rst
+++ /dev/null
@@ -1,5 +0,0 @@
-Fix a dangling input pointer in :class:`lzma.LZMADecompressor`,
-:class:`bz2.BZ2Decompressor`, and internal :class:`!zlib._ZlibDecompressor`
-when memory allocation fails with :exc:`MemoryError`, which could let a
-subsequent :meth:`!decompress` call read or write through a stale pointer to
-the already-released caller buffer.
diff --git 
a/Misc/NEWS.d/next/Security/2026-04-20-15-31-37.gh-issue-148808._Z8JL0.rst 
b/Misc/NEWS.d/next/Security/2026-04-20-15-31-37.gh-issue-148808._Z8JL0.rst
deleted file mode 100644
index 0b5cf85fedfba1..00000000000000
--- a/Misc/NEWS.d/next/Security/2026-04-20-15-31-37.gh-issue-148808._Z8JL0.rst
+++ /dev/null
@@ -1,3 +0,0 @@
-Added buffer boundary check when using ``nbytes`` parameter with
-:meth:`!asyncio.AbstractEventLoop.sock_recvfrom_into`. Only
-relevant for Windows and the :class:`asyncio.ProactorEventLoop`.
diff --git 
a/Misc/NEWS.d/next/Security/2026-04-21-13-46-30.gh-issue-90309.srvj9q.rst 
b/Misc/NEWS.d/next/Security/2026-04-21-13-46-30.gh-issue-90309.srvj9q.rst
deleted file mode 100644
index d7d376737e4ad1..00000000000000
--- a/Misc/NEWS.d/next/Security/2026-04-21-13-46-30.gh-issue-90309.srvj9q.rst
+++ /dev/null
@@ -1,3 +0,0 @@
-Base64-encode values when embedding cookies to JavaScript using the
-:meth:`http.cookies.BaseCookie.js_output` method to avoid injection
-and escaping.
diff --git 
a/Misc/NEWS.d/next/Security/2026-04-26-17-49-58.gh-issue-149017.EiVFPo.rst 
b/Misc/NEWS.d/next/Security/2026-04-26-17-49-58.gh-issue-149017.EiVFPo.rst
deleted file mode 100644
index 6aa7efb68a1981..00000000000000
--- a/Misc/NEWS.d/next/Security/2026-04-26-17-49-58.gh-issue-149017.EiVFPo.rst
+++ /dev/null
@@ -1 +0,0 @@
-Update bundled `libexpat <https://libexpat.github.io/>`_ to version 2.8.0.
diff --git 
a/Misc/NEWS.d/next/Security/2026-05-02-16-22-20.gh-issue-149254.9ozXB9.rst 
b/Misc/NEWS.d/next/Security/2026-05-02-16-22-20.gh-issue-149254.9ozXB9.rst
deleted file mode 100644
index f89f84790ca0f7..00000000000000
--- a/Misc/NEWS.d/next/Security/2026-05-02-16-22-20.gh-issue-149254.9ozXB9.rst
+++ /dev/null
@@ -1 +0,0 @@
-Update Android and iOS installer to use OpenSSL 3.0.20.
diff --git 
a/Misc/NEWS.d/next/Windows/2026-03-27-22-06-10.gh-issue-146458.fYj0UQ.rst 
b/Misc/NEWS.d/next/Windows/2026-03-27-22-06-10.gh-issue-146458.fYj0UQ.rst
deleted file mode 100644
index 178c04c657ecbb..00000000000000
--- a/Misc/NEWS.d/next/Windows/2026-03-27-22-06-10.gh-issue-146458.fYj0UQ.rst
+++ /dev/null
@@ -1 +0,0 @@
-Fix incorrect REPL height and width tracking on console window resize on 
Windows.
diff --git 
a/Misc/NEWS.d/next/Windows/2026-05-03-14-07-51.gh-issue-149254.ENtMYD.rst 
b/Misc/NEWS.d/next/Windows/2026-05-03-14-07-51.gh-issue-149254.ENtMYD.rst
deleted file mode 100644
index 5b7f20dff7c6fc..00000000000000
--- a/Misc/NEWS.d/next/Windows/2026-05-03-14-07-51.gh-issue-149254.ENtMYD.rst
+++ /dev/null
@@ -1 +0,0 @@
-Updated bundled version of OpenSSL to 3.0.20.
diff --git 
a/Misc/NEWS.d/next/macOS/2026-05-01-19-38-16.gh-issue-149254.enO7uj.rst 
b/Misc/NEWS.d/next/macOS/2026-05-01-19-38-16.gh-issue-149254.enO7uj.rst
deleted file mode 100644
index a58e6fc8bb89d5..00000000000000
--- a/Misc/NEWS.d/next/macOS/2026-05-01-19-38-16.gh-issue-149254.enO7uj.rst
+++ /dev/null
@@ -1 +0,0 @@
-Update macOS installer to use OpenSSL 3.0.20.
diff --git a/README.rst b/README.rst
index aa399a69fe5ae9..44147bd874a970 100644
--- a/README.rst
+++ b/README.rst
@@ -1,5 +1,5 @@
-This is Python version 3.14.4
-=============================
+This is Python version 3.14.5 release candidate 1
+=================================================
 
 .. image:: 
https://github.com/python/cpython/actions/workflows/build.yml/badge.svg?branch=main&event=push
    :alt: CPython build status on GitHub Actions

_______________________________________________
Python-checkins mailing list -- [email protected]
To unsubscribe send an email to [email protected]
https://mail.python.org/mailman3//lists/python-checkins.python.org
Member address: [email protected]

Reply via email to
diff --git a/Lib/pydoc_data/topics.py b/Lib/pydoc_data/topics.py
index 6dca99ce9b1c7a..0022d44efc76a2 100644
--- a/Lib/pydoc_data/topics.py
+++ b/Lib/pydoc_data/topics.py
@@ -1,4 +1,4 @@
-# Autogenerated by Sphinx on Tue Apr  7 16:13:12 2026
+# Autogenerated by Sphinx on Mon May  4 18:31:32 2026
 # as part of the release process.
 
 topics = {
@@ -6594,8 +6594,9 @@ def whats_on_the_telly(penguin=None):
 
 1. find a module, loading and initializing it if necessary
 
-2. define a name or names in the local namespace for the scope where
-   the "import" statement occurs.
+2. define a name or names in the current namespace for the scope where
+   the "import" statement occurs, just as an assignment statement
+   would (including "global" and "nonlocal" semantics).
 
 When the statement contains multiple clauses (separated by commas) the
 two steps are carried out separately for each clause, just as though
@@ -6640,7 +6641,7 @@ def whats_on_the_telly(penguin=None):
 
    3. if the attribute is not found, "ImportError" is raised.
 
-   4. otherwise, a reference to that value is stored in the local
+   4. otherwise, a reference to that value is stored in the current
       namespace, using the name in the "as" clause if it is present,
       otherwise using the attribute name
 
@@ -10739,8 +10740,18 @@ class is used in a class pattern with positional 
arguments, each
 str.swapcase()
 
    Return a copy of the string with uppercase characters converted to
-   lowercase and vice versa. Note that it is not necessarily true that
-   "s.swapcase().swapcase() == s".
+   lowercase and vice versa. For example:
+
+      >>> 'Hello World'.swapcase()
+      'hELLO wORLD'
+
+   Note that it is not necessarily true that "s.swapcase().swapcase()
+   == s". For example:
+
+      >>> 'straße'.swapcase().swapcase()
+      'strasse'
+
+   See also "str.lower()" and "str.upper()".
 
 str.title()
 